Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(187)

Unified Diff: sdk/lib/io/platform.dart

Issue 45103002: Deprecate dart:io Platform, replaced by dart:platform. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fix dartium failure on path_separator_test. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tests/lib/platform/path_separator_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/io/platform.dart
diff --git a/sdk/lib/io/platform.dart b/sdk/lib/io/platform.dart
index 30a9a9f40bb00463707878476bbf53d374e87c13..467242a35f707bc888863c3a209edf89bc951293 100644
--- a/sdk/lib/io/platform.dart
+++ b/sdk/lib/io/platform.dart
@@ -4,9 +4,23 @@
part of dart.io;
+@deprecated
/**
* The [Platform] class exposes details of the machine and operating
* system.
+ *
+ * This class has been replaced by adding the dart:platform library to Dart.
+ * dart:platform is available on all browser and standalone platforms,
+ * including Dart code that has been compiled to javascript.
+ *
+ * The dart:platform class has
+ * the same top-level getters as the members of [Platform], except that the
+ * [isWindows], [isLinux], [isAndroid], and [isMacOS] getters
+ * have been removed. On platforms supporting dart:io, the getters of
+ * dart:platform have the same values as the Platform class members, except
+ * that [script] has been changed from a [String] to a file [Uri].
+ *
+ * The [Platform] class may be removed as early as November 1, 2013.
*/
class Platform {
static final _numberOfProcessors = _Platform.numberOfProcessors;
@@ -4,9 +4,23 @@
/**
- * The [Platform] class exposes details of the machine and operating
+ * Deprecated: the [Platform] class exposes details of the machine and operating
* system.
« no previous file with comments | « no previous file | tests/lib/platform/path_separator_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698